@@ -1,6 +1,6 @@
 package Pithub;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01037';
+our $VERSION = '0.01038';
 # ABSTRACT: Github v3 API
 
 use Moo;
@@ -112,12 +112,11 @@ Pithub - Github v3 API
 
 =head1 VERSION
 
-version 0.01037
+version 0.01038
 
 =head1 SYNOPSIS
 
-    use Pithub;
-    use Data::Dumper;
+    use Pithub ();
 
     my $p = Pithub->new;
     # my $p = Pithub->new(utf8 => 0); # enable compatibility options for version 0.01029 or lower
