@@ -1,6 +1,6 @@
 package Pithub::Base;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01037';
+our $VERSION = '0.01038';
 # ABSTRACT: Github v3 base class for all Pithub modules
 
 use Moo;
@@ -223,7 +223,7 @@ sub request {
     }
 
     if ( $self->_token_required( $method, $path ) && !$self->has_token($request) ) {
-        croak sprintf "Access token required for: %s %s (%s)", $method, $path, $uri;
+        croak sprintf 'Access token required for: %s %s (%s)', $method, $path, $uri;
     }
 
     if ($options) {
@@ -258,7 +258,7 @@ sub _make_request {
     if( my $cached_response = $self->shared_cache->get($request->uri) ) {
         # Add the If-None-Match header from the cache's ETag
         # and make the request
-        $request->header( "If-None-Match" => $cached_response->header("ETag") );
+        $request->header( 'If-None-Match' => $cached_response->header('ETag') );
         my $response = $self->ua->request($request);
 
         # Got 304 Not Modified, cache is still valid
@@ -418,7 +418,7 @@ Pithub::Base - Github v3 base class for all Pithub modules
 
 =head1 VERSION
 
-version 0.01037
+version 0.01038
 
 =head1 DESCRIPTION
 
