@@ -1,6 +1,6 @@
 package Pithub::Orgs::Teams;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01037';
+our $VERSION = '0.01038';
 # ABSTRACT: Github v3 Org Teams API
 
 use Moo;
@@ -10,7 +10,7 @@ extends 'Pithub::Base';
 
 sub add_member {
     my ( $self, %args ) = @_;
-    carp '"Add team member" API is deprecated. Use add_membership method.';
+    carp q{"Add team member" API is deprecated. Use add_membership method.};
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: user'    unless $args{user};
     return $self->request(
@@ -143,7 +143,7 @@ sub list_repos {
 
 sub remove_member {
     my ( $self, %args ) = @_;
-    carp '"Remove team member" API is deprecated. Use remove_membership method.';
+    carp q{"Remove team member" API is deprecated. Use remove_membership method.};
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: user'    unless $args{user};
     return $self->request(
@@ -203,7 +203,7 @@ Pithub::Orgs::Teams - Github v3 Org Teams API
 
 =head1 VERSION
 
-version 0.01037
+version 0.01038
 
 =head1 METHODS
 
